@@ -4,6 +4,7 @@
 utils::globalVariables(c(
  # Column names used in dplyr operations
  "athlete_id",
+ "country",
  "display_name",
  "event_id",
  "hole",
@@ -12,9 +13,17 @@ utils::globalVariables(c(
  "player_id",
  "player_name",
  "position",
+ "rounds",
  "score",
  "score_display",
  "score_type",
+ "sg_app",
+ "sg_arg",
+ "sg_ott",
+ "sg_putt",
+ "sg_t2g",
+ "sg_total",
+ "strokes_gained",
  "total_score",
  "tournament_id",
  "tournament_name",
